"""
Copyright © 2020-2025 Ralph Seichter

This file is part of "Fangfrisch".

Fangfrisch is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fangfrisch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fangfrisch. If not, see <https://www.gnu.org/licenses/>.
"""

CLEANUP = "cleanup"
DB_URL = "db_url"
ENABLED = "enabled"
INTEGRITY_CHECK = "integrity_check"
INTERVAL = "interval"
LOCAL_DIR = "local_directory"
LOG_FORMAT = "log_format"
LOG_LEVEL = "log_level"
LOG_METHOD = "log_method"
LOG_METHOD_CONSOLE = "console"
LOG_METHOD_SYSLOG = "syslog"
LOG_TARGET = "log_target"
MAX_SIZE = "max_size"
ON_UPDATE_EXEC = "on_update_exec"
PREFIX = "prefix"
